/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.ui.purchases

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import de.chaosdorf.meteroid.sync.SyncHandler
import de.chaosdorf.meteroid.ui.navigation.HomeSections
import de.chaosdorf.meteroid.ui.navigation.MeteroidBottomBar
import de.chaosdorf.meteroid.ui.navigation.MeteroidTopBar

@Composable
fun PurchaseListScreen(
  viewModel: PurchaseViewModel,
  onNavigate: (route: String) -> Unit = {}
) {
  val account by viewModel.account.collectAsState()
  val purchases by viewModel.purchases.collectAsState()
  val syncState by viewModel.syncState.collectAsState()

  Scaffold(
    topBar = { MeteroidTopBar(account, onNavigate) },
    bottomBar = {
      MeteroidBottomBar(
        currentRoute = HomeSections.HISTORY,
        historyEnabled = account?.second?.audit == true,
        navigateTo = onNavigate
      )
    }
  ) { paddingValues: PaddingValues ->
    Column {
      if (syncState == SyncHandler.State.Loading) {
        LinearProgressIndicator()
      }
      LazyColumn(modifier = Modifier.padding(paddingValues)) {
        items(purchases) { (purchase, drink) ->
          PurchaseListItem(purchase, drink)
        }
      }
    }
  }
}
