/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.ui.users

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.ListItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.unit.dp
import de.chaosdorf.mete.UserId
import de.chaosdorf.meteroid.sync.SyncHandler

@Composable
fun UserListScreen(
  viewModel: UserListViewModel,
  onAdd: () -> Unit = {},
  onSelect: (UserId) -> Unit = {},
  onBack: () -> Unit = {},
) {
  val server by viewModel.account.collectAsState()
  val users by viewModel.users.collectAsState()
  val syncState by viewModel.syncState.collectAsState()

  Scaffold(
    topBar = {
      TopAppBar(
        title = {
          Text(
            server?.first?.name
              ?: "Meteroid"
          )
        },
        navigationIcon = {
          IconButton(onClick = { onBack() }) {
            Icon(Icons.AutoMirrored.Default.ArrowBack, contentDescription = "Back")
          }
        },
        modifier = Modifier.shadow(4.dp)
      )
    }
  ) { paddingValues ->
    Column {
      if (syncState == SyncHandler.State.Loading) {
        LinearProgressIndicator()
      }
      LazyColumn(modifier = Modifier.padding(paddingValues)) {
        items(users) { user ->
          ListItem(
            headlineContent = { Text(user.name) },
            supportingContent = { Text(user.email) },
            modifier = Modifier.clickable { onSelect(user.userId) }
          )
        }
        item {
          ListItem(
            headlineContent = { Text("Add User") },
            modifier = Modifier.clickable { onAdd() }
          )
        }
      }
    }
  }
}
